@@ -2,20 +2,18 @@ import logging
 import os
 
 from tutum.api import auth
-from tutum.api.cluster import Cluster
+from tutum.api.service import Service
 from tutum.api.container import Container
-from tutum.api.registry import Registry
 from tutum.api.image import Image
 from tutum.api.node import Node
 from tutum.api.nodecluster import NodeCluster
 from tutum.api.nodetype import NodeType
-from tutum.api.provider import Provider
-from tutum.api.region import Region
-from tutum.api.availabilityzones import AZ
+from tutum.api.nodeprovider import Provider
+from tutum.api.noderegion import Region
 from tutum.api.exceptions import TutumApiError, TutumAuthError
 
 
-__version__ = '0.8.0pre'
+__version__ = '0.9.0pre'
 
 #: The username used to authenticate with the API
 user = auth.load_from_file()[0] or os.environ.get('TUTUM_USER', None)
