@@ -46,7 +46,10 @@ class RESTModel(object):
 
         :returns: str -- the primary key for the object
         """
-        return getattr(self, self._pk_key(), None)
+        if hasattr(self, '_pk_key'):
+            return self._pk_key()
+        else:
+            return None
 
     @classmethod
     def _pk_key(cls):
@@ -70,7 +73,7 @@ class RESTModel(object):
 
         :returns: list -- a list of objects that match the query
         """
-        containers = []
+        objects = []
         endpoint = getattr(cls, 'endpoint', None)
         assert endpoint, "Endpoint not specified for %s" % cls.__name__
         json = send_request('GET', endpoint, params=kwargs)
@@ -79,8 +82,9 @@ class RESTModel(object):
             for json_obj in json_objects:
                 instance = cls()
                 instance._loaddict(json_obj)
-                containers.append(instance)
-        return containers
+                objects.append(instance)
+        return objects
+
 
     @classmethod
     def fetch(cls, pk):
@@ -174,7 +178,7 @@ class RESTModel(object):
         else:
             # Object deleted successfully and nothing came back - deleting PK reference.
             self._detail_uri = None
-            setattr(self, self._pk_key(), None)
+            # setattr(self, self._pk_key(), None) -- doesn't work
             self.__setchanges__([])
         return True
 
